#
# spec file for package python-Sphinx
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-Sphinx
Version:        1.2.3
Release:        1.2
Url:            http://sphinx.pocoo.org
Summary:        Python documentation generator
License:        BSD-2-Clause
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/S/Sphinx/Sphinx-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-devel
BuildRequires:  python-setuptools
# Documentation requirements:
BuildRequires:  python-Jinja2 >= 2.3
BuildRequires:  python-docutils >= 0.7
# Testsuite requirements:
BuildRequires:  python-Pygments >= 1.2
BuildRequires:  python-nose
Requires(post): update-alternatives
Requires(postun): update-alternatives
Requires:       python-Jinja2 >= 2.3
Requires:       python-Pygments >= 1.2
Requires:       python-docutils >= 0.7
Suggests:       python-rst2pdf
Provides:       python-sphinx = %{version}
Obsoletes:      python-sphinx < %{version}
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Sphinx is a tool that makes it easy to create intelligent and beautiful
documentation for Python projects (or other documents consisting of multiple
reStructuredText sources), written by Georg Brandl.  It was originally created
for the new Python documentation, and has excellent facilities for Python
project documentation, but C/C++ is supported as well, and more languages are
planned.

Sphinx uses reStructuredText as its markup language, and many of its strengths
come from the power and straightforwardness of reStructuredText and its parsing
and translating suite, the Docutils.

%package        doc
Summary:        Documentation for %{name}
Group:          Documentation/Other
Requires:       %{name} = %{version}

%description    doc
Sphinx is a tool that makes it easy to create intelligent and beautiful
documentation for Python projects (or other documents consisting of multiple
reStructuredText sources), written by Georg Brandl.  It was originally created
for the new Python documentation, and has excellent facilities for Python
project documentation, but C/C++ is supported as well, and more languages are
planned.

Sphinx uses reStructuredText as its markup language, and many of its strengths
come from the power and straightforwardness of reStructuredText and its parsing
and translating suite, the Docutils.

%prep
%setup -q -n Sphinx-%{version}
sed -i '/#\!/d' sphinx/pycode/pgen2/token.py # Fix non-excutable-script warning
# Add Interpreter version suffix to entrypoints (and thus /usr/bin binaries) to
# allow for update-alternatives later on:
sed -i 's/\(sphinx-.*\) =/\1-%{py_ver} =/' setup.py
# Fix wrong end-of-line encoding
sed -i 's/\r$//' sphinx/themes/basic/static/jquery.js

%build
python setup.py build
python setup.py build_sphinx && rm build/sphinx/html/.buildinfo
python setup.py build_sphinx -b man

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
for B in apidoc autogen build quickstart ; do
  touch %{buildroot}%{_sysconfdir}/alternatives/sphinx-$B
  ln -sf %{_sysconfdir}/alternatives/sphinx-$B %{buildroot}/%{_bindir}/sphinx-$B
done
install -d %{buildroot}%{_mandir}/man1/
for M in all apidoc build quickstart ; do
  install -m 644 build/sphinx/man/sphinx-$M.1 %{buildroot}%{_mandir}/man1/sphinx-$M-%{py_ver}.1
  touch %{buildroot}%{_sysconfdir}/alternatives/sphinx-$M.1.gz
  ln -sf %{_sysconfdir}/alternatives/sphinx-$M.1.gz %{buildroot}%{_mandir}/man1/sphinx-$M.1.gz
done
%find_lang sphinx

%check
PYTHONPATH=$PWD make test

%post
update-alternatives \
    --install %{_bindir}/sphinx-apidoc sphinx-apidoc %{_bindir}/sphinx-apidoc-%{py_ver} 20 \
    --slave %{_bindir}/sphinx-build sphinx-build %{_bindir}/sphinx-build-%{py_ver} \
    --slave %{_bindir}/sphinx-autogen sphinx-autogen %{_bindir}/sphinx-autogen-%{py_ver} \
    --slave %{_bindir}/sphinx-quickstart sphinx-quickstart %{_bindir}/sphinx-quickstart-%{py_ver} \
    --slave %{_mandir}/man1/sphinx-all.1.gz sphinx-all.1 %{_mandir}/sphinx-all-%{py_ver}.1.gz \
    --slave %{_mandir}/man1/sphinx-apidoc.1.gz sphinx-apidoc.1 %{_mandir}/sphinx-apidoc-%{py_ver}.1.gz \
    --slave %{_mandir}/man1/sphinx-build.1.gz sphinx-build.1 %{_mandir}/sphinx-build-%{py_ver}.1.gz \
    --slave %{_mandir}/man1/sphinx-quickstart.1.gz sphinx-quickstart.1 %{_mandir}/sphinx-quickstart-%{py_ver}.1.gz \

%postun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove sphinx-apidoc %{_bindir}/sphinx-apidoc-%{py_ver}
fi

%files -f sphinx.lang
%defattr(-,root,root,-)
%doc AUTHORS CHANGES LICENSE README.rst
%{_bindir}/sphinx-apidoc
%{_bindir}/sphinx-apidoc-%{py_ver}
%{_bindir}/sphinx-autogen
%{_bindir}/sphinx-autogen-%{py_ver}
%{_bindir}/sphinx-build
%{_bindir}/sphinx-build-%{py_ver}
%{_bindir}/sphinx-quickstart
%{_bindir}/sphinx-quickstart-%{py_ver}
%{_mandir}/man1/sphinx-all.1.gz
%{_mandir}/man1/sphinx-all-%{py_ver}.1.gz
%{_mandir}/man1/sphinx-apidoc.1.gz
%{_mandir}/man1/sphinx-apidoc-%{py_ver}.1.gz
%{_mandir}/man1/sphinx-build.1.gz
%{_mandir}/man1/sphinx-build-%{py_ver}.1.gz
%{_mandir}/man1/sphinx-quickstart.1.gz
%{_mandir}/man1/sphinx-quickstart-%{py_ver}.1.gz
%{python_sitelib}/sphinx/
%{python_sitelib}/Sphinx-%{version}-py%{py_ver}.egg-info
%ghost %{_sysconfdir}/alternatives/sphinx-apidoc
%ghost %{_sysconfdir}/alternatives/sphinx-autogen
%ghost %{_sysconfdir}/alternatives/sphinx-build
%ghost %{_sysconfdir}/alternatives/sphinx-quickstart
%ghost %{_sysconfdir}/alternatives/sphinx-all.1.gz
%ghost %{_sysconfdir}/alternatives/sphinx-apidoc.1.gz
%ghost %{_sysconfdir}/alternatives/sphinx-build.1.gz
%ghost %{_sysconfdir}/alternatives/sphinx-quickstart.1.gz

%files doc
%defattr(-,root,root,-)
%doc EXAMPLES build/sphinx/html

%changelog
* Tue Sep  9 2014 toddrme2178@gmail.com
- Update to 1.2.3:
  + Features added
  * #1518: `sphinx-apidoc` command now have a `--version` option to show version
    information and exit
  * New locales: Hebrew, European Portuguese, Vietnamese.
  + Bugs fixed
  * #636: Keep straight single quotes in literal blocks in the LaTeX build.
  * #1419: Generated i18n sphinx.js files are missing message catalog entries
    from '.js_t' and '.html'. The issue was introduced from Sphinx-1.1
  * #1363: Fix i18n: missing python domain's cross-references with currentmodule
    directive or currentclass directive.
  * #1444: autosummary does not create the description from attributes docstring.
  * #1457: In python3 environment, make linkcheck cause "Can't convert 'bytes'
    object to str implicitly" error when link target url has a hash part.
    Thanks to Jorge_C.
  * #1467: Exception on Python3 if nonexistent method is specified by automethod
  * #1441: autosummary can't handle nested classes correctly.
  * #1499: With non-callable `setup` in a conf.py, now sphinx-build emits
    user-friendly error message.
  * #1502: In autodoc, fix display of parameter defaults containing backslashes.
  * #1226: autodoc, autosummary: importing setup.py by automodule will invoke
    setup process and execute `sys.exit()`. Now sphinx avoids SystemExit
    exception and emits warnings without unexpected termination.
  * #1503: py:function directive generate incorrectly signature when specifying
    a default parameter with an empty list `[]`. Thanks to Geert Jansen.
  * #1508: Non-ASCII filename raise exception on make singlehtml, latex, man,
    texinfo and changes.
  * #1531: On Python3 environment, docutils.conf with 'source_link=true' in the
    general section cause type error.
  * PR#270, #1533: Non-ASCII docstring cause UnicodeDecodeError when uses with
    inheritance-diagram directive. Thanks to WAKAYAMA shirou.
  * PR#281, PR#282, #1509: TODO extension not compatible with websupport. Thanks
    to Takeshi Komiya.
  * #1477: gettext does not extract nodes.line in a table or list.
  * #1544: `make text` generate wrong table when it has empty table cells.
  * #1522: Footnotes from table get displayed twice in LaTeX. This problem has
    been appeared from Sphinx-1.2.1 by #949.
  * #508: Sphinx every time exit with zero when is invoked from setup.py command.
    ex. `python setup.py build_sphinx -b doctest` return zero even if doctest
    failed.
* Thu Mar  6 2014 mcihar@suse.cz
- Update to 1.2.2:
  - PR#211: When checking for existence of the html_logo file, check the full
    relative path and not the basename.
  - PR#212: Fix traceback with autodoc and __init__ methods without docstring.
  - PR#213: Fix a missing import in the setup command.
  - #1357: Option names documented by option are now again allowed to not start
    with a dash or slash, and referencing them will work correctly.
  - #1358: Fix handling of image paths outside of the source directory when
    using the “wildcard” style reference.
  - #1374: Fix for autosummary generating overly-long summaries if first line
    doesn’t end with a period.
  - #1383: Fix Python 2.5 compatibility of sphinx-apidoc.
  - #1391: Actually prevent using “pngmath” and “mathjax” extensions at the
    same time in sphinx-quickstart.
  - #1386: Fix bug preventing more than one theme being added by the entry
    point mechanism.
  - #1370: Ignore “toctree” nodes in text writer, instead of raising.
  - #1364: Fix ‘make gettext’ fails when the ‘.. todolist::’ directive is
    present.
  - #1367: Fix a change of PR#96 that break
    sphinx.util.docfields.Field.make_field interface/behavior for item argument
    usage.
* Mon Feb 10 2014 speilicke@suse.com
- Update to version 1.2.1
  + See CHANGES
- Fix update-alternatives usage
- Removed sphinx-setup_command_unicode.patch (upstream)
* Mon Nov 18 2013 speilicke@suse.com
- Fix %%preun update-alternatives, used wrong master
* Fri Nov 15 2013 speilicke@suse.com
- Only ghost /etc/alternatives on 12.3 or newer
* Wed Nov 13 2013 speilicke@suse.com
- Add sphinx-setup_command_unicode.patch: Backport of
  https://bitbucket.org/birkenfeld/sphinx/pull-request/193/
* Wed Nov  6 2013 speilicke@suse.com
- Updateo version 1.2b3:
  + The Sphinx error log files will now include a list of the loaded extensions
    for help in debugging.
  + PR#154: Remove "sphinx" prefix from LaTeX class name except 'sphinxmanual'
    and 'sphinxhowto'. Now you can use your custom document class without
    'sphinx' prefix. Thanks to Erik B.
  + #1265: Fix i18n: crash when translating a section name that is pointed to from
    a named target.
  + A wrong condition broke the search feature on first page that is usually
    index.rst.  This issue was introduced in 1.2b1.
  + #703: When Sphinx can't decode filenames with non-ASCII characters, Sphinx now
    catches UnicodeError and will continue if possible instead of raising the
    exception.
- Changes from version 1.2b2 and prior:
  + See CHANGES file
- Own /etc/alternatives/sphinx-* by ghosting (update-alternatives)
- Dropped sphinx-docutils-0.10.patch (merged upstream)
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Thu Jul 18 2013 speilicke@suse.com
- Drop runtime req on python-distribute
* Tue Jul  9 2013 dmueller@suse.com
- add sphinx-docutils-0.10.patch:
  * add support for docutils 0.10
* Thu May 16 2013 speilicke@suse.com
- Fix update-alternatives and support upgrade from previous versions
* Tue Apr 30 2013 speilicke@suse.com
- Apply update-alternatives for binaries and man-pages
* Tue Nov 20 2012 saschpe@suse.de
- Run testsuite
- Build and install man-pages
* Thu Nov 15 2012 saschpe@suse.de
- Revert last "locale" change, it was a false positive
* Tue Nov  6 2012 saschpe@suse.de
- Remove obsolete SUSE version checks
- Don't package locale files twice
* Wed May 23 2012 highwaystar.ru@gmail.com
- python3 package added
* Wed May 23 2012 saschpe@suse.de
- Update to version 1.1.13:
  * PR#40: Fix safe_repr function to decode bytestrings with non-ASCII
    characters correctly.
  * PR#37: Allow configuring sphinx-apidoc via SPHINX_APIDOC_OPTIONS.
  * PR#34: Restore Python 2.4 compatibility.
  * PR#36: Make the "bibliography to TOC" fix in LaTeX output specific to
    the document class.
  * #695: When the highlight language "python" is specified explicitly,
    do not try to parse the code to recognize non-Python snippets.
  * #859: Fix exception under certain circumstances when not finding
    appropriate objects to link to.
  * #860: Do not crash when encountering invalid doctest examples, just
    emit a warning.
  * #864: Fix crash with some settings of :confval:modindex_common_prefix.
  * #862: Fix handling of -D and -A options on Python 3.
  * #851: Recognize and warn about circular toctrees, instead of running
    into recursion errors.
  * #853: Restore compatibility with docutils trunk.
  * #852: Fix HtmlHelp index entry links again.
  * #854: Fix inheritance_diagram raising attribute errors on builtins.
  * #832: Fix crashes when putting comments or lone terms in a glossary.
  * #834, #818: Fix HTML help language/encoding mapping for all Sphinx
    supported languages.
  * #844: Fix crashes when dealing with Unicode output in doctest extension.
  * #831: Provide --project flag in setup_command as advertised.
  * #875: Fix reading config files under Python 3.
  * #876: Fix quickstart test under Python 3.
  * #870: Fix spurious KeyErrors when removing documents.
  * #892: Fix single-HTML builder misbehaving with the master document in a
    subdirectory.
  * #873: Fix assertion errors with empty only directives.
  * #816: Fix encoding issues in the Qt help builder.
* Thu Nov 10 2011 saschpe@suse.de
- Update to version 1.1.2:
  * #809: Include custom fixers in the source distribution.
- Changes from version 1.1.1:
  * #791: Fix QtHelp, DevHelp and HtmlHelp index entry links.
  * #792: Include "sphinx-apidoc" in the source distribution.
  * #797: Don't crash on a misformatted glossary.
  * #801: Make intersphinx work properly without SSL support.
  * #805: Make the Sphinx.add_index_to_domain method work correctly.
  * #780: Fix Python 2.5 compatibility.
* Thu Sep 22 2011 saschpe@suse.de
- Require python-docutils instead of docutils
- Change license to BSD-2-Clause (SPDX style, according to LICENSE)
* Wed Aug 31 2011 saschpe@suse.de
- Corrected buildrequires/requires:
  * python-jinja2 is now python-Jinja2
  * python-pygments is now python-Pygments
* Tue Jul 12 2011 mcihar@suse.cz
- add python-distribute to Requires, it is needed to run sphinx-build
* Sun Jul  3 2011 saschpe@gmx.de
- Renamed to 'python-Sphinx', obsoletes 'python-sphinx'
- Update to version 1.0.7:
  * #347: Fix wrong generation of directives of static methods in
    autosummary.
  * #599: Import PIL as from PIL import Image.
  * #558: Fix longtables with captions in LaTeX output.
  * Make token references work as hyperlinks again in LaTeX output.
  * #572: Show warnings by default when reference labels cannot be
    found.
  * #536: Include line number when complaining about missing reference
    targets in nitpicky mode.
  * #590: Fix inline display of graphviz diagrams in LaTeX output.
  * #589: Build using app.build() in setup command.
  * Fix a bug in the inheritance diagram exception that caused base
    classes to be skipped if one of them is a builtin.
  * Fix general index links for C++ domain objects.
  * #332: Make admonition boundaries in LaTeX output visible.
  * #573: Fix KeyErrors occurring on rebuild after removing a file.
  * Fix a traceback when removing files with globbed toctrees.
  * If an autodoc object cannot be imported, always re-read the
    document containing the directive on next build.
  * If an autodoc object cannot be imported, show the full traceback
    of the import error.
  * Fix a bug where the removal of download files and images wasn't
    noticed.
  * #571: Implement ~ cross-reference prefix for the C domain.
  * Fix regression of LaTeX output with the fix of #556.
  * #568: Fix lookup of class attribute documentation on descriptors
    so that comment documentation now works.
  * Fix traceback with only directives preceded by targets.
  * Fix tracebacks occurring for duplicate C++ domain objects.
  * Fix JavaScript domain links to objects with $ in their name.
- Spec file cleanup:
  * Use fdupes and %%find_lang
  * Removed authors from description
  * Make doc package on require %%{version}, not %%{release}
* Wed Jan 12 2011 saschpe@suse.de
- Spec file cleanup
  * correct doc package group, no dupes
  * added rpmlintrc file
- Update to 1.0.6
  * #581: Fix traceback in Python domain for empty cross-reference
    targets.
  * #283: Fix literal block display issues on Chrome browsers.
  * #383, #148: Support sorting a limited range of accented
    characters in the general index and the glossary.
  * #570: Try decoding -D and -A command-line arguments with
    the locale's preferred encoding.
  * #528: Observe locale_dirs when looking for the JS
    translations file.
  * #574: Add special code for better support of Japanese documents
    in the LaTeX builder.
  * Regression of #77: If there is only one parameter given with
    :param: markup, the bullet list is now suppressed again.
  * #556: Fix missing paragraph breaks in LaTeX output in certain
    situations.
  * #567: Emit the autodoc-process-docstring event even for objects
    without a docstring so that it can add content.
  * #565: In the LaTeX builder, not only literal blocks require
    different table handling, but also quite a few other list-like
    block elements.
  * #515: Fix tracebacks in the viewcode extension for Python objects
    that do not have a valid signature.
  * Fix strange reportings of line numbers for warnings generated
    from autodoc-included docstrings, due to different behavior
    depending on docutils version.
  * Several fixes to the C++ domain.
* Mon Jan  3 2011 nix@opensuse.org
- Update to 1.0.5
* Wed Sep  8 2010 nix@opensuse.org
- Update to 1.0.3
* Mon Apr 26 2010 nix@opensuse.org
- Update to 0.6.5
* Tue Aug 11 2009 cfarrell@suse.de
- Update to 0.6.2 and split docs into separate package
* Fri Jun  5 2009 poeml@suse.de
- initial package (0.6.1)
